@@ -83,7 +83,7 @@ Adjuster::Adjuster (Glib::ustring vlabel, double vmin, double vmax, double vstep
     }
 
     reset = Gtk::manage (new Gtk::Button ());
-    reset->add (*Gtk::manage (new RTImage ("undo-small.png", "redo-small.png")));
+    reset->add (*Gtk::manage (new RTImage ("undo-small.svg", "redo-small.svg")));
     setExpandAlignProperties(reset, false, false, Gtk::ALIGN_CENTER, Gtk::ALIGN_CENTER);
     reset->set_relief (Gtk::RELIEF_NONE);
     reset->set_tooltip_markup(M("ADJUSTER_RESET_TO_DEFAULT"));
@@ -140,7 +140,7 @@ Adjuster::Adjuster (Glib::ustring vlabel, double vmin, double vmax, double vstep
         Gtk::HBox *hb = nullptr;
         if (deprecated) {
             hb = Gtk::manage(new Gtk::HBox());
-            Gtk::Image *w = Gtk::manage(new RTImage("warning-small.png"));
+            Gtk::Image *w = Gtk::manage(new RTImage("warning-small.svg"));
             w->set_tooltip_markup(M("GENERAL_DEPRECATED_TOOLTIP"));
             hb->pack_start(*w, Gtk::PACK_SHRINK, 2);
             hb->pack_start(*label, Gtk::PACK_SHRINK);
@@ -192,7 +192,7 @@ Adjuster::Adjuster (Glib::ustring vlabel, double vmin, double vmax, double vstep
             spin->get_increments(step, page);
 
             if (!ctrl && !shift && !alt) {
-                switch (evt->keyval) {
+                switch (getKeyval(evt)) {
                 case GDK_KEY_Up:
                     spin->set_value(spin->get_value() + step);
                     return true;
@@ -232,7 +232,7 @@ void Adjuster::addAutoButton (Glib::ustring tooltip)
 {
     if (!automatic) {
         automatic = new Gtk::CheckButton ();
-        //automatic->add (*Gtk::manage (new RTImage ("gears.png")));
+        //automatic->add (*Gtk::manage (new RTImage ("gears.svg")));
         automatic->set_tooltip_markup(tooltip.length() ? Glib::ustring::compose("<b>%1</b>\n\n%2", M("GENERAL_AUTO"), tooltip) : M("GENERAL_AUTO"));
         setExpandAlignProperties(automatic, false, false, Gtk::ALIGN_CENTER, Gtk::ALIGN_CENTER);
         autoChange = automatic->signal_toggled().connect( sigc::mem_fun(*this, &Adjuster::autoToggled) );
