@@ -100,7 +100,7 @@ public:
     {
     }
 
-    Gtk::Widget *getWidget() override
+    Gtk::Container *getContainer() override
     {
         return parent_->box;
     }
@@ -195,7 +195,7 @@ public:
     
     Glib::ustring getColumnHeader(int col) override
     {
-        return M("TP_COLORCORRECTION_LIST_TITLE");
+        return M("TP_LABMASKS_PARAMETERS");
     }
     
     Glib::ustring getColumnContent(int col, int row) override
