@@ -42,7 +42,7 @@ public:
         return "smoothing";
     }
 
-    Gtk::Widget *getWidget() override
+    Gtk::Container *getContainer() override
     {
         return parent_->box;
     }
@@ -133,7 +133,7 @@ public:
     
     Glib::ustring getColumnHeader(int col) override
     {
-        return M("TP_SMOOTHING_LIST_TITLE");
+        return M("TP_LABMASKS_PARAMETERS");
     }
     
     Glib::ustring getColumnContent(int col, int row) override
