@@ -866,8 +866,20 @@ void ThumbBrowserEntryBase::resize (int h)
 
 void ThumbBrowserEntryBase::drawFrame(Cairo::RefPtr<Cairo::Context> cc, const Gdk::RGBA &bg, const Gdk::RGBA &fg)
 {
-    int radius = 4;
+    Glib::RefPtr<Gtk::StyleContext> style = parent->getStyle();
+    
+    static int radius = -1;
+    if (radius < 0) {
+        Gtk::Button btn("");
+        auto ctx = btn.get_style_context();
 
+        gtk_style_context_get(ctx->gobj(),
+                              gtk_style_context_get_state(ctx->gobj()),
+                              GTK_STYLE_PROPERTY_BORDER_RADIUS, &radius,
+                              NULL);
+        radius *= 1.5;
+    }
+    
     cc->move_to (radius, 0);
     cc->arc (exp_width - 1 - radius, radius, radius, -rtengine::RT_PI / 2, 0);
     cc->arc (exp_width - 1 - radius, exp_height - 1 - radius, radius, 0, rtengine::RT_PI / 2);
