@@ -663,8 +663,12 @@ void Thumbnail::getOriginalSize(int &w, int &h, bool consider_coarse)
     }
     w = cfs.width;
     h = cfs.height;
-    if (consider_coarse && pparamsValid) {
-        if (pparams.master.coarse.rotate == 90 || pparams.master.coarse.rotate == 270) {
+    if (consider_coarse) {
+        int rotate = infoFromImage(fname);
+        if (pparamsValid) {
+            rotate = (rotate + pparams.master.coarse.rotate) % 360;
+        }
+        if (rotate == 90 || rotate == 270) {
             std::swap(w, h);
         }
     }
